using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.IO;

namespace UiColumnsInterpreters
{
	/// <summary>
	/// Implementers of this interface must also have a parameterless constructor,
	/// which will be used to construct them before use.
	/// </summary>
	public interface IItemInterpreter
	{
		/// <summary>
		/// Implementers should return the guid of the item type for which they can interpret the value.
		/// </summary>
		Guid TypeGuid { get; }

		/// <summary>
		/// Implementers should provide the name of the item type they can interpret
		/// </summary>
		string TypeName { get; }

		/// <summary>
		/// Implementers must take the byte array that is the value in the cfg, and write out
		/// XML to completely describe it to the XmlWriter.
		/// <param name="itemInterpreters">All loaded item interpreters, keyed by guid, so if this item has sub-items, they can be passed on for processing</param>
		/// </summary>
		void WriteValueToXml(XmlWriter writer, byte[] itemSettings, Dictionary<Guid, IItemInterpreter> itemInterpreters);

		/// <summary>
		/// Implementers must take the Xml Element that was written out by <see cref="WriteValueToXml"/>
		/// and reproduce the bytes that produced it, writing them to the Stream
		/// <param name="itemInterpreters">All loaded item interpreters, keyed by name, so if this item has sub-items, they can be passed on for processing</param>
		/// </summary>
		void WriteXmlToValue(Stream writer, XmlElement itemSettings, Dictionary<string, IItemInterpreter> itemInterpreters);
	}
}
