using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Xml;
using FooCfgToXml;

namespace UiColumnsInterpreters.ItemInterpreters.Blanks
{
	#region Abstract blank
	/// <summary>
	/// There are no special settings for these items, but this ensures that they will be given
	/// friendly names, as it is often important to know where they appears.
	/// </summary>
	public abstract class BlankItemInterpreter : IItemInterpreter
	{
		private string mName;
		private Guid mGuid;

		protected BlankItemInterpreter(string name, string guid)
		{
			mName = name;
			mGuid = new Guid(guid);
		}

		public Guid TypeGuid
		{
			get { return mGuid; }
		}
		public string TypeName
		{
			get { return mName; }
		}

		public void WriteValueToXml(XmlWriter writer, byte[] itemSettings, Dictionary<Guid, IItemInterpreter> itemInterpreters)
		{
			CfgToXmlUtilities.WriteByteArrayToXml(writer, itemSettings);
		}

		public void WriteXmlToValue(Stream writer, XmlElement itemSettings, Dictionary<string, IItemInterpreter> itemInterpreters)
		{
			XmlToCfgUtilities.WriteXmlToByteArray(writer, itemSettings);
		}
	}
	#endregion

	public class ColumnsPlaylistBlank : BlankItemInterpreter
	{
		public ColumnsPlaylistBlank()
			: base("Columns Playlist", "f20bed8f-225b-46c3-9fc7-454cedb6cdad")
		{
		}
	}
	public class MenuBlank : BlankItemInterpreter
	{
		public MenuBlank()
			: base("Menu", "76e6db50-0de3-4f30-a7e4-93fd628b1401")
		{
		}
	}
	public class PlaybackOrderBlank : BlankItemInterpreter
	{
		public PlaybackOrderBlank()
			: base("Playback order", "aba09e7e-9c95-443e-bdfc-049d66b324a0")
		{
		}
	}
	public class PlaylistsDropdownBlank : BlankItemInterpreter
	{
		public PlaylistsDropdownBlank()
			: base("Playlists Dropdown", "00d8e874-2909-486a-a8cb-69b5ab11ca46")
		{
		}
	}
	public class QuickSearchToolbarBlank : BlankItemInterpreter
	{
		public QuickSearchToolbarBlank()
			: base("Quick Search Toolbar", "fabdf72e-d1f0-11da-9b41-b622a1ef5492")
		{
		}
	}
	public class SeekbarBlank : BlankItemInterpreter
	{
		public SeekbarBlank()
			: base("Seekbar", "678fe380-abbb-4c72-a0b3-72e769671125")
		{
		}
	}
	public class VolumeBlank : BlankItemInterpreter
	{
		public VolumeBlank()
			: base("Volume", "b3259290-cb68-4d37-b0f1-8094862a9524")
		{
		}
	}
}
