using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Xml;
using FooCfgToXml;

namespace UiColumnsInterpreters.ItemInterpreters
{
	public class SpectrumAnalyserItemInterpreter : IItemInterpreter
	{
		private static readonly Guid sGuid = new Guid("d947777c-94c7-409a-b02c-9b0eb9e374fa");

		private static readonly string[] sWindowFrameStyles = new string[] { "None", "Sunken", "Grey" };

		public Guid TypeGuid
		{
			get { return sGuid; }
		}
		public string TypeName
		{
			get { return "Spectrum analyser"; }
		}

		public void WriteValueToXml(XmlWriter writer, byte[] itemSettings, Dictionary<Guid, IItemInterpreter> itemInterpreters)
		{
			if (itemSettings.Length == 0)
				return;

			MemoryStream reader = new MemoryStream(itemSettings, false);

			writer.WriteStartElement("SpectrumAnalyser");
			writer.WriteAttributeString("windowFrameStyle", CfgToXmlUtilities.ReadEnum(reader, sWindowFrameStyles));
			CfgToXmlUtilities.ReadInt(reader); //The size of the settings is not useful, discard it.

			byte[] foreground = new byte[4];
			reader.Read(foreground, 0, foreground.Length);

			byte[] background = new byte[4];
			reader.Read(background, 0, background.Length);

			writer.WriteAttributeString("barsMode", XmlConvert.ToString(CfgToXmlUtilities.ReadInt(reader) == 1)); //Int as bool

			writer.WriteStartElement("Foreground");
			Utilities.WriteColorToXml(writer, foreground);
			writer.WriteEndElement(); //foreground

			writer.WriteStartElement("Background");
			Utilities.WriteColorToXml(writer, background);
			writer.WriteEndElement(); //background

			writer.WriteEndElement(); //SpectrumAnalyser
		}

		public void WriteXmlToValue(Stream writer, XmlElement itemSettings, Dictionary<string, IItemInterpreter> itemInterpreters)
		{
			if (itemSettings.ChildNodes.Count == 0)
				return;

			XmlElement spectrumAnalyser = (XmlElement)itemSettings.FirstChild; //Should be first and only child

			XmlToCfgUtilities.WriteEnum(writer, spectrumAnalyser.GetAttribute("windowFrameStyle"), sWindowFrameStyles);
			XmlToCfgUtilities.WriteInt(writer, 12); //Size is a constant

			Utilities.WriteColorToCfg(writer, (XmlElement)spectrumAnalyser.SelectSingleNode("Foreground"));
			Utilities.WriteColorToCfg(writer, (XmlElement)spectrumAnalyser.SelectSingleNode("Background"));
			XmlToCfgUtilities.WriteInt(writer, XmlConvert.ToBoolean(spectrumAnalyser.GetAttribute("barsMode")) ? 1 : 0); //Int as bool
		}
	}
}
