using System;
using System.Collections.Generic;
using System.Text;
using FooCfgToXml;
using System.Xml;
using System.IO;
using System.Reflection;

namespace UiColumnsInterpreters
{
	public class LayoutsInterpreter : IValueInterpreter
	{
		private static readonly Guid sSettingGuid = new Guid("755971a7-109b-41dc-bed9-5a05cc07c905");

		public Guid SettingGuid
		{
			get { return sSettingGuid; }
		}

		public void WriteValueToXml(XmlWriter writer, byte[] value)
		{
			Dictionary<Guid, IItemInterpreter> itemInterpreters = FooCfgToXml.Utilities.LoadAddins<Guid, IItemInterpreter>(delegate(IItemInterpreter itemInterpreter) { return itemInterpreter.TypeGuid; });

			MemoryStream reader = new MemoryStream(value, false);

			writer.WriteStartElement("Layouts");

			writer.WriteAttributeString("flag", XmlConvert.ToString(CfgToXmlUtilities.ReadInt(reader))); //This always appears to be 0. Don't know what its for, so give it a generic name
			writer.WriteAttributeString("activeLayout", XmlConvert.ToString(CfgToXmlUtilities.ReadInt(reader)));

			int numberOfLayouts = CfgToXmlUtilities.ReadInt(reader);
			
			for (int i = 0; i < numberOfLayouts; i++)
			{
				writer.WriteStartElement("Layout");

				IItemInterpreter itemInterpreter = Utilities.WriteItemTypeToXml(writer, reader, itemInterpreters);

				writer.WriteAttributeString("name", CfgToXmlUtilities.ReadString(reader, false));

				Utilities.WriteItemSettingsToXml(writer, reader, itemInterpreter, itemInterpreters);

				writer.WriteEndElement(); //Layout
			}
			writer.WriteEndElement(); //Layouts
		}

		public void WriteXmlToValue(Stream writer, XmlElement value)
		{
			Dictionary<string, IItemInterpreter> itemInterpreters = FooCfgToXml.Utilities.LoadAddins<string, IItemInterpreter>(delegate(IItemInterpreter itemInterpreter) { return itemInterpreter.TypeName; });

			XmlElement layouts = (XmlElement)value.FirstChild; //Should be first and only child
			XmlToCfgUtilities.WriteInt(writer, XmlConvert.ToInt32(layouts.GetAttribute("flag")));
			XmlToCfgUtilities.WriteInt(writer, XmlConvert.ToInt32(layouts.GetAttribute("activeLayout")));
			
			XmlNodeList layoutElements = layouts.SelectNodes("Layout");
			XmlToCfgUtilities.WriteInt(writer, layoutElements.Count);
			foreach (XmlElement layout in layoutElements)
			{
				IItemInterpreter itemInterpreter = Utilities.WriteItemTypeToCfg(writer, layout, itemInterpreters);

				XmlToCfgUtilities.WriteString(writer, layout.GetAttribute("name"), true, false);

				Utilities.WriteItemSettingsToCfg(writer, layout, itemInterpreter, itemInterpreters);
			}
		}
	}
}
