using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Xml;

namespace FilterCfgXml
{
	partial class Program
	{
		private static void FilterCfgXml(FileInfo fileInfo, IEnumerable<string> componentNames)
		{
			Console.WriteLine("Filtering \"{0}\":", fileInfo.FullName);

			XmlDocument xmlDoc = new XmlDocument();
			try
			{
				xmlDoc.Load(fileInfo.FullName);
			}
			catch (Exception e)
			{
				Console.WriteLine("Could not read \"{0}\":\n{1}", fileInfo.Name, e.Message);
				return;
			}

			//Start writing out the settings
			try
			{
				//Open the output file
				if (fileInfo.Exists)
				{
					Console.WriteLine(" Deleting existing \"{0}\"", fileInfo.Name);
					try
					{
						fileInfo.Delete();
					}
					catch (Exception e)
					{
						Console.WriteLine("Aborting: could not delete file: {0}", e.Message);
						return;
					}
				}

				XmlWriterSettings settings = new XmlWriterSettings();
				settings.Indent = true;
				using (XmlWriter writer = XmlWriter.Create(fileInfo.FullName, settings))
				{
					writer.WriteStartDocument();
					writer.WriteStartElement("Config");

					Console.WriteLine();
					Console.WriteLine(" Writing components");
					foreach (string componentName in componentNames)
					{
						bool foundComponent = false;
						foreach(XmlElement component in xmlDoc.SelectNodes(String.Format("/Config/Component[@name='{0}']", componentName)))
						{
							//Only expecting one, but there could potentially be more than one match?
							component.WriteTo(writer);
							Console.WriteLine("  {0}: OK", componentName);
							foundComponent = true;
						}
						if(!foundComponent)
							Console.WriteLine("  {0}: Not found!", componentName);
					}

					writer.WriteEndDocument();
				}
				Console.WriteLine();
			}
			catch (Exception e)
			{
				Console.WriteLine("Could not write to \"{0}\":\n{1}", fileInfo.Name, e.Message);
				return;
			}

			Console.WriteLine(" Successfully filtered!");
		}
	}
}
