using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.IO;

namespace FooCfgToXml
{
	/// <summary>
	/// Implementers of this interface must also have a parameterless constructor,
	/// which will be used to construct them before use.
	/// </summary>
	public interface IValueInterpreter
	{
		/// <summary>
		/// Implementers should return the guid of the setting for which they can interpret the value.
		/// </summary>
		Guid SettingGuid { get; }

		/// <summary>
		/// Implementers must take the byte array that is the value in the cfg, and write out
		/// XML to completely describe it to the XmlWriter.
		/// </summary>
		void WriteValueToXml(XmlWriter writer, byte[] value);

		/// <summary>
		/// Implementers must take the Xml Element that was written out by <see cref="WriteValueToXml"/>
		/// and reproduce the bytes that produced it, writing them to the Stream
		/// </summary>
		void WriteXmlToValue(Stream writer, XmlElement value);
	}
}
