using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;
using System.IO;

namespace FooCfgToXml
{
	public static class Utilities
	{
		public delegate TKey GetKeyDelegate<TKey, TAddin>(TAddin addin);

		/// <summary>
		/// Finds dll's in the execution folder, and checks them for types implementing <see cref="TAddin"/>
		/// They are returned in a dictionary keyed by the result of running <see cref="getKeyDelegate"/> on
		/// each addin that is found and instantiated.
		/// </summary>
		public static Dictionary<TKey, TAddin> LoadAddins<TKey, TAddin>(GetKeyDelegate<TKey, TAddin> getKeyDelegate)
		{
			Dictionary<TKey, TAddin> addins = new Dictionary<TKey, TAddin>();

			string searchPath = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
			try
			{
				DirectoryInfo folder = new DirectoryInfo(searchPath);
				foreach (FileInfo assemblyFile in folder.GetFiles("*.dll"))
				{
					try
					{
						Assembly assembly = Assembly.LoadFile(assemblyFile.FullName);
						foreach (Type type in assembly.GetExportedTypes())
						{
							try
							{
								if (type.IsClass && !type.IsAbstract && typeof(TAddin).IsAssignableFrom(type))
								{
									TAddin addin = (TAddin)Activator.CreateInstance(type);
									addins.Add(getKeyDelegate(addin), addin);
								}
							}
							catch (Exception e1)
							{
								Console.WriteLine("Could not load addin: {0}\n\n from: \"{1}\":\n\n {2}\n", type.AssemblyQualifiedName, assemblyFile.FullName, e1.Message);
							}
						}
					}
					catch (Exception e2)
					{
						Console.WriteLine("Could not load addins from: \"{0}\":\n\n {1}\n", assemblyFile.FullName, e2.Message);
					}
				}
			}
			catch (Exception e3)
			{
				Console.WriteLine("Could not load addins from \"{0}\":\n\n {1}\n", searchPath, e3.Message);
			}

			return addins;
		}
	}
}
