using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Xml;

namespace MergeCfgXml
{
	partial class Program
	{
		private static void MergeCfgXml(FileInfo targetFile, FileInfo sourceFile)
		{
			Console.WriteLine("Merging \"{0}\"\n   into \"{1}\":", sourceFile.FullName, targetFile.FullName);

			XmlDocument sourceDoc = LoadXmlDoc(sourceFile);
			XmlDocument targetDoc = LoadXmlDoc(targetFile);
			if (sourceDoc == null || targetDoc == null)
				return;

			//Start merging the settings
			Console.WriteLine();
			Console.WriteLine(" Merging components");

			//Go through each component in the source
			foreach (XmlElement sourceComponent in sourceDoc.SelectNodes("/Config/Component"))
			{
				string componentName = sourceComponent.GetAttribute("name");

				bool targetExisted = false;
				//Find the equivalent component(s?) in the target, and remove them
				foreach (XmlElement targetComponent in targetDoc.SelectNodes(String.Format("/Config/Component[@name='{0}']", componentName)))
				{
					targetDoc.DocumentElement.RemoveChild(targetComponent);
					targetExisted = true;
				}

				//Add the component to the target
				targetDoc.DocumentElement.AppendChild(targetDoc.ImportNode(sourceComponent, true));

				Console.WriteLine("  {0}: {1}", componentName, targetExisted ? "Replaced" : "Added");
			}
			try
			{
				Console.WriteLine();
				Console.WriteLine(" Writing merged file");
				targetDoc.Save(targetFile.FullName);
			}
			catch (Exception e)
			{
				Console.WriteLine("Could not write to \"{0}\":\n{1}", targetFile.Name, e.Message);
				return;
			}

			Console.WriteLine();
			Console.WriteLine(" Successfully merged!");
		}

		private static XmlDocument LoadXmlDoc(FileInfo fileInfo)
		{
			XmlDocument doc = new XmlDocument();
			try
			{
				doc.Load(fileInfo.FullName);
			}
			catch (Exception e)
			{
				Console.WriteLine("Could not read \"{0}\":\n{1}", fileInfo.Name, e.Message);
				return null;
			}
			return doc;
		}
	}
}
