using System;
using System.Collections.Generic;
using System.Text;
using System.IO;

namespace MergeCfgXml
{
	partial class Program
	{
		static void Main(string[] args)
		{
			DisplayTitle();
			if (args.Length == 0)
				DisplayHelp();
			else if (args.Length != 2)
			{
				Console.WriteLine("Must specify exactly two filenames");
				DisplayHelp();
			}
			else
			{
				try
				{
					//Read the target
					FileInfo targetFile = new FileInfo(args[0]);
					if (!targetFile.Exists)
					{
						Console.WriteLine("File does not exist: \"{0}\"", args[0]);
					}
					else
					{
						//Read the source
						try
						{
							FileInfo sourceFile = new FileInfo(args[1]);
							if (!sourceFile.Exists)
							{
								Console.WriteLine("File does not exist: \"{0}\"", args[1]);
							}
							else
							{
								MergeCfgXml(targetFile, sourceFile);
							}
						}
						catch (Exception e)
						{
							Console.WriteLine("Could not read \"{0}\":\n {1}", args[1], e.Message);
						}

					}
				}
				catch (Exception e)
				{
					Console.WriteLine("Could not read \"{0}\":\n {1}", args[0], e.Message);
				}
			}
#if DEBUG
			Console.ReadLine();
#endif
		}

		private static void DisplayTitle()
		{
			String title = String.Format("foobar2000 XML config file merger {0}", System.Reflection.Assembly.GetEntryAssembly().GetName().Version);
			Console.WriteLine();
			Console.WriteLine(title);
			Console.WriteLine(new String('=', title.Length));
			Console.WriteLine();
		}

		private static void DisplayHelp()
		{
			Console.WriteLine();
			Console.WriteLine("Usage: MergeCfgXml.exe foobar2000.cfg.xml partial.cfg.xml");
			Console.WriteLine();
			Console.WriteLine("Examples:");
			Console.WriteLine();
			Console.WriteLine(@"FilterCfgXml.exe ""C:\Program Files\foobar2000\foobar2000.cfg.xml"" ""C:\Downloads\Playlist.cfg.xml""");
			Console.WriteLine();
			Console.WriteLine("  Takes the contents of the xml config file Playlist.cfg.xml and merges them");
			Console.WriteLine("  in to the file foobar2000.cfg.xml. The settings specified in Playlist.cfg.xml");
			Console.WriteLine("  will overwrite those in foobar2000.cfg.xml, but any other existing settings");
			Console.WriteLine("  will remain unchanged.");
			Console.WriteLine();
		}
	}
}
